import path from 'path';
const toString = Object.prototype.toString;
export function is(val, type) {
    return toString.call(val) === `[object ${type}]`;
}
export function isFunction(val) {
    return is(val, 'Function');
}
export function isArray(val) {
    return val && Array.isArray(val);
}
export function isRegExp(val) {
    return is(val, 'RegExp');
}
export function isNumber(val) {
    return is(val, 'Number');
}
export function isBoolean(val) {
    return is(val, 'Boolean');
}
export function sleep(time) {
    return new Promise((resolve) => {
        setTimeout(() => {
            resolve('');
        }, time);
    });
}
export function param2Obj(url) {
    const search = url.split('?')[1];
    if (!search) {
        return {};
    }
    return JSON.parse('{"' +
        decodeURIComponent(search)
            .replace(/"/g, '\\"')
            .replace(/&/g, '","')
            .replace(/=/g, '":"')
            .replace(/\+/g, ' ') +
        '"}');
}
export async function loadConfigFromBundledFile(fileName, bundledCode) {
    const extension = path.extname(fileName);
    const defaultLoader = require.extensions[extension];
    require.extensions[extension] = (module, filename) => {
        if (filename === fileName) {
            module._compile(bundledCode, filename);
        }
        else {
            defaultLoader(module, filename);
        }
    };
    delete require.cache[fileName];
    const raw = require(fileName);
    const config = raw.__esModule ? raw.default : raw;
    require.extensions[extension] = defaultLoader;
    return config;
}
